@@ -907,6 +907,10 @@ class FormatExt4(FormatExt2):
     format_util = "/sbin/mkfs.ext4"
 
 
+class FormatExfat(FormatProcessGeneric):
+    format_util = "/sbin/mkfs.exfat"
+
+
 class FormatJfs(FormatProcessGeneric):
     format_util = "/sbin/mkfs.jfs"
 
@@ -1000,6 +1004,7 @@ class PartitionDistributive(Distributive):
         'ext2': FormatExt2,
         'ext3': FormatExt3,
         'ext4': FormatExt4,
+        'exfat': FormatExfat,
         'jfs': FormatJfs,
         'f2fs': FormatF2FS,
         'reiserfs': FormatReiserfs,
